@@ -246,7 +246,8 @@ Normalization hint: N+M
 
 The well-known plotting style for step patterns
 
->>> #TODO plot(symmetricP2,main="Sakoe's Symmetric P=2 recursion")
+>>> import matplotlib.pyplot as plt;		# doctest: +SKIP
+... symmetricP2.plot().set_title("Sakoe's Symmetric P=2 recursion")
 
 Same example seen in ?dtw , now with asymmetric step pattern
 
@@ -254,11 +255,13 @@ Same example seen in ?dtw , now with asymmetric step pattern
 
 Do the computation
 
->>> asy = dtw(query,reference,keep_internals=True,step_pattern=asymmetric);
+>>> asy = dtw(query, reference, keep_internals=True,
+... 	  	     step_pattern=asymmetric);
 
->>> #TODO dtwPlot(asy,type="density",main="Sine and cosine, asymmetric step")
+>>> dtwPlot(asy,type="density"			# doctest: +SKIP
+...         ).set_title("Sine and cosine, asymmetric step")
 
-Hand-checkable example given in [Myers1980] p 61
+Hand-checkable example given in [Myers1980] p 61 - see JSS paper
 
 >>> tm = numpy.reshape( [1, 3, 4, 4, 5, 2, 2, 3, 3, 4, 3, 1, 1, 1, 3, 4, 2,
 ...                      3, 3, 2, 5, 3, 4, 4, 1], (5,5), "F" )
